@@ -13,7 +13,7 @@ use t::lib::Custom ();
 use t::lib::MyClass ();
 use t::lib::MyHtmlWindow ();
 
-our $VERSION = '0.76';
+our $VERSION = '0.77';
 our @ISA     = 'Wx::Dialog';
 
 sub new {
@@ -212,6 +212,14 @@ sub new {
 		],
 	);
 
+	Wx::Event::EVT_COMBOBOX(
+		$self,
+		$self->{m_comboBox1},
+		sub {
+			shift->on_combobox(@_);
+		},
+	);
+
 	Wx::Event::EVT_TEXT(
 		$self,
 		$self->{m_comboBox1},
@@ -958,6 +966,10 @@ sub toggle_me {
 	warn 'Handler method toggle_me for event m_toggleBtn1.OnToggleButton not implemented';
 }
 
+sub on_combobox {
+	warn 'Handler method on_combobox for event m_comboBox1.OnCombobox not implemented';
+}
+
 sub list_col_click {
 	warn 'Handler method list_col_click for event m_listCtrl1.OnListColClick not implemented';
 }
